#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quickcheck-assertions
version:              0.3.0
visibility:           public
id:                   quickcheck-assertions-0.3.0-KxQJJa4GCtdEskZiE4XJGW
key:                  quickcheck-assertions-0.3.0-KxQJJa4GCtdEskZiE4XJGW
license:              LGPL-3.0-only
maintainer:           s9gf4ult@gmail.com
author:               Aleksey Uymanov
homepage:             https://github.com/s9gf4ult/quickcheck-assertions
synopsis:             HUnit like assertions for QuickCheck
description:
    Library with convenient assertions for QuickCheck properties like in HUnit

category:             Testing
abi:                  664db91edebcf895f94903405e3649ab
exposed:              True
exposed-modules:      Test.QuickCheck.Assertions
import-dirs:          /usr/lib/ghc-9.6.6/site-local/quickcheck-assertions-0.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/quickcheck-assertions-0.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/quickcheck-assertions-0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-assertions
hs-libraries:         HSquickcheck-assertions-0.3.0-KxQJJa4GCtdEskZiE4XJGW
depends:
    QuickCheck-2.15.0.1-GIIsjuuZeTD5REN3cOn4Nc base-4.18.2.1
    ieee754-0.8.0-EGVgNa4vggOEmRT3C9pqtp
    pretty-show-1.10-EXsS4VwIV5tJ56gbmVdfrR

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-assertions/html/quickcheck-assertions.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-assertions/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

